/**
 *#########################################################################
 *
 * A component of the Gatherer application, part of the Greenstone digital
 * library suite from the New Zealand Digital Library Project at the
 * University of Waikato, New Zealand.
 *
 * <BR><BR>
 *
 * Author: John Thompson, Greenstone Digital Library, University of Waikato
 *
 * <BR><BR>
 *
 * Copyright (C) 1999 New Zealand Digital Library Project
 *
 * <BR><BR>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * <BR><BR>
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * <BR><BR>
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *########################################################################
 */

 




package org.greenstone.gatherer.help;
/**
 * Title:        The Gatherer<br>
 * Description:  The Gatherer: a tool for gathering and enriching digital collections.<br>
 * Copyright:    Copyright (c) 2001<br>
 * Company:      The University of Waikato<br>
 * @author John Thompson, Greenstone Digital Libraries
 * @version 2.1
 */
import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.net.URL;
import java.util.Vector;
import javax.swing.tree.DefaultMutableTreeNode;
import org.greenstone.gatherer.util.Utility;
/** This class provides a wrapper around a <strong>DefaultMutableTreeNode</strong> which provides the ability to set an html page to be loaded when this node is selected. */
public class HelpItem 
	 extends DefaultMutableTreeNode {
	 /** The file name of the html page to load. */
	 public String file_name = null;
	 /** The title to be displayed for this tree node. */
	 public String title = null;
	 /** Default Construtor with no file and no title. */
	 public HelpItem() {
		  this.file_name = null;
		  this.title = "No Content";
	 }
	 /** Constructor.
	  * @param title The title to be shown for this node as a <strong>String</strong>.
	  */
	 public HelpItem(String title) {
		  this.file_name = null;
		  this.title = title;
	 }
	 /** Constructor.
	  * @param title The title to be shown for this node as a <strong>String</strong>.
	  * @param file_name The name of the html file as a <strong>String</strong>.
	  */
	 public HelpItem(String title, String file_name) {
		  this.file_name = file_name;
		  this.title = title;

		  file_name = file_name.replace('/', File.separatorChar);
		  file_name = file_name.replace('\\', File.separatorChar);
	 }
	 /** This method reads in the html file then returns it as one long string.
	  * @return A <strong>String</strong> containing the entire html files contents.
	  */
	 public String content() {
		  String content = "";
		  try {
				File file = new File(file_name);
				FileReader in_reader = new FileReader(file);
				BufferedReader in = new BufferedReader(in_reader, 
																	Utility.BUFFER_SIZE);
				String line;
				while((line = in.readLine()) != null) {
					 content = content + line;
				}
		  }
		  catch (Exception e) {
		  }
		  return content;
	 }
	 /** Method to get the file name.
	  * @return The file name as a <strong>String</strong>.
	  */
	 public String getFileName() {
		  return file_name;
	 }
	 /** Method to create a url from the file name. This method is preferred over the <i>content()</i> method, as the url can then be directly parsed by the html renderer.
	  * @return A <strong>URL</strong> that points to the files location as determined by the file name.
	  */
	 public URL getURL() {
		  URL url = null; 
		  if(file_name != null) {
				try {
					 File file = new File(file_name);
					 url = file.toURL();
				}
				catch (Exception e) {
				}
		  }
		  return url;
	 }
	 /** Method to acquire a string representation of this node, which in this case is its title.
	  * @return A <strong>String</strong> which shows how this node should be displayed in the tree for example.
	  */
	 public String toString() {
		  return title;
	 }
}



